@@ -83,8 +83,11 @@ class Liquid:
     # pylint: enable=unused-argument
 
     def __del__(self):
-        if self.meta.should_close:
-            self.meta.stream.close()
+        try:
+            if self.meta.should_close:
+                self.meta.stream.close()
+        except AttributeError: # pragma: no cover
+            pass
 
     def _update_context(self, context):
         # type: (Dict[str, Any]) -> Dict[str, Any]
@@ -132,7 +135,9 @@ class LiquidPython(Liquid):
     PARSER_CLASS = ParserPython
     FILTER_MANAGER = filter_manager_python
 
-    __new__ = object.__new__
+    # pylint: disable=signature-differs,unused-argument,arguments-differ
+    def __new__(cls, *args, **kwargs):
+        return object.__new__(cls)
 
     def render(self, **context):
         # type: (Any) -> str
